@@ -14,7 +14,7 @@ use FindBin qw/$Bin/;
 use Path::Class;
 use base qw/Exporter/;
 
-our $VERSION = 0.2;
+our $VERSION = 0.3;
 our ($name)  = $PROGRAM_NAME =~ m{^.*/(.*?)$}mxs;
 our $tmux_conf    = file "$ENV{HOME}", '.tmux.conf';
 our $tmux_layout  = dir "$ENV{HOME}", '.tmux', 'layout';
@@ -183,16 +183,16 @@ sub _auto {
         print join "\n", glob "$current*";
     }
     else {
-        my $dir = $previous =~ /^-l$|^--layout$/ ? $tmux_layout : $tmux_devmode;
-        my @found = grep {
-                !/^[.]/
+        my $dir = $previous =~ /^-\w*l$|^--layout$/ ? $tmux_layout : $tmux_devmode;
+        my @found = sort {
+                lc $a cmp lc $b
+            }
+            grep {
+                !$current || /^$current/i
             }
             map {
                 m{/([^/]+)$}; $1
             }
-            grep {
-                !$current || /$current/
-            }
             $dir->children;
         print join "\n", @found, '';
     }
@@ -208,7 +208,7 @@ App::Devmode2 - A tmux session loading tool
 
 =head1 VERSION
 
-This documentation refers to App::Devmode2 version 0.2
+This documentation refers to App::Devmode2 version 0.3
 
 =head1 SYNOPSIS
 
